Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetRetryAtTime ¶
GetRetryAtTime returns the time from a retryAtError, or nil.
func IsNoRetryError ¶
IsNoRetryError returns whether an error is a NoRetryError
func IsStepError ¶ added in v0.6.0
func NoRetryError ¶
NoRetryError wraps an error, preventing retries in the SDK. This permanently fails a step and function.
Types ¶
type StepError ¶ added in v0.6.0
type StepError struct {
Name string `json:"name"`
Message string `json:"message"`
// Data is the data from state.UserError, used to store
// the resulting value when step errors occur with an additional
// response type.
Data json.RawMessage `json:"data,omitempty"`
}
StepError is an error returned when a step permanently fails
Click to show internal directories.
Click to hide internal directories.